import { NextResponse } from "next/server";
import dbConnect from "@/lib/mongodb";
import Product from "@/models/Product";

export async function GET() {
  try {
    await dbConnect();
    const products = await Product.find({});
    return NextResponse.json(products);
  } catch (error) {
    console.error("获取商品列表失败:", error);
    return NextResponse.json({ error: "获取商品列表失败" }, { status: 500 });
  }
}

// 添加商品的接口
export async function POST(request) {
  try {
    await dbConnect();
    const data = await request.json();

    // 确保所有必需字段都存在，使用默认值
    const productData = {
      title: data.title,
      price: data.price,
      sales: data.sales || 0,
      stock: data.stock || 100, // 添加默认值
      imageUrl: data.imageUrl,
      isVip: data.isVip || false,
      description: data.description || "给它一份沉沉的爱，一个暖暖的家！", // 添加默认值
      features: data.features || [
        // 添加默认值
        "不用担心扯拉客人",
        "加密底网防止兔子受伤",
        "双层空间更舒适",
        "带有自动清粪功能",
        "顶部天窗设计",
        "贯通阁楼",
        "加密间距",
        "抽拉托盘",
      ],
      services: data.services || ["7天无理由退货", "闪电退款", "货到付款"], // 添加默认值
      delivery: data.delivery || "物流配送", // 添加默认值
    };

    // 打印要创建的数据
    console.log("准备创建的商品数据:", productData);

    const product = await Product.create(productData);
    return NextResponse.json(product);
  } catch (error) {
    console.error("创建商品失败:", error);
    return NextResponse.json(
      { error: "创建商品失败", details: error.message },
      { status: 500 }
    );
  }
}
